#!/bin/bash

apppath="$1"

if [ "$apppath" = "" ]; then
echo "No app loaded.... Please drag and drop an app to get the Team and Bundle ID"
exit 0
fi
#This will get the Team and bundle ID's.  codesign is printing its output to stderr so a lot of awk string replacement was needed.

IDS=$(/usr/bin/codesign -dv "$1" 2>&1 | grep -o 'Identifier.*' | awk 'NR==1,/Identifier=/{sub(/Identifier=/, "BundleID: ")} 1' | awk 'NR==1,/Identifier=/{sub(/Identifier=/, "TeamID: ")} 1')

echo " "
echo "Full App Information"
echo "----------------------------------------------------------------"
echo " "
/usr/bin/codesign -d --deep --verbose=2 -r- "${apppath}"
echo " "
echo " "
echo "##############################################################"

echo "App Icon Conversion Info:"
echo "----------------------------------------------------------------"
#Get current logged in user
user=`/bin/ls -l /dev/console | /usr/bin/awk '{ print $3 }'`
#get User ID
uid=$(id -u "$user")

appName=$(/usr/bin/defaults read "${apppath}/Contents/Info.plist" CFBundleExecutable)
iconName=$(/usr/bin/defaults read "${apppath}"/Contents/Info.plist CFBundleIconFile)


if [ "$iconName" != "" ]; then
	if [[ "${iconName##*.}" != "icns" ]]; then
		icnsName="${iconName}.icns"
	else
		icnsName="${iconName}"
	fi
else
	echo "No icon information was found in the application's Info.plist."
fi

#Icon Variables
iconPath=$(echo "${apppath}"/Contents/Resources/"$icnsName")
copyIcon=$(/bin/launchctl asuser "$uid" /bin/cp "$iconPath" /Users/Shared)
cpIconPath=$(echo "/Users/Shared/"$icnsName"")


#Convert the icon to a png
sips -s format png "$cpIconPath" --out /Users/Shared/"$appName.png"
sips -z 128 128 /Users/Shared/"$appName.png"

#Ask user if they want to save the app icon to their desktop
buttonClicked=$(/usr/bin/osascript <<END
set myAnswer to button returned of (display dialog "Would you like to export the App Icon to your Desktop?" buttons {"Yes", "No"} default button "No")
return myAnswer
END
)

if [[ "$buttonClicked" = "Yes" ]]; then
	/bin/mv -f /Users/Shared/"$appName.png" ~/Desktop
	else
	/bin/rm -f /Users/Shared/"$appName.png"	
fi

#remove icon from /Users/Shared
/bin/rm -f /Users/Shared/"$icnsName"
echo " "
echo " "
echo " "
echo " "
echo " "
echo " "
echo " "
echo " "
echo " "
echo "                                ^^"
echo "                                ^^"
echo "                                ^^"
echo "                                ^^"
echo "                                ^^"
echo "Scroll up for additional info   ^^  "		
echo "##################################"
echo " "
echo "$IDS"
echo " "
exit 0